==> v0.4.9.zip: libarea/app/Languages/zh_TW/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => '更详细',
    'category'          => '类别',
    'categories'        => '类别',
    'audits'            => '审计',
    'soft'              => '软件',
    'website'           => '网站',
    'websites'          => '网站',
    'on_website'        => '到网站',
    'deleted'           => '已删除',
    'facets'            => '方面',
    'favorites'         => '书签',
    'menu'              => '菜单',
    'no'                => '非也',
    'yes'               => '是的',
    'title'             => '标题',
    'description'       => '资料描述',
    'catalog'           => '目录',
    'find'              => '找到',
    'help'              => '提示',
    'deny_replies'      => '禁止回应？',
    'posted'            => '张贴？',
    'necessarily'       => '需要填写',
    'status'            => '链接状态',
    'there_program'     => '有计划吗？',
    'there_forum'       => '网站上有论坛吗？',
    'there_portal'      => '这是传送门吗？',
    'there_blog'        => '这是个人博客吗？',
    'there_reference'   => '这是一个参考网站（百科全书）吗？',
    'hosted_github'     => '程序是否托管在GitHub上？',
    'url_github'        => 'GitHub上存储库的URL',
    'related_posts'     => '相关职位',
    'desc_formed'       => '描述正在形成',
    'by_date'           => '按日期计算',
    'top_view'          => '按评级划分',
    'new_sites'         => '新网站',
    'audits_view'       => '需要考虑',
    'deleted_view'      => '已删除',
    'my_website'        => '我的网站',
    'no_website'        => '目前还没有网站',
    'bookmarks'         => '按网站划分的书签',
    'bookmarks_view'    => '我的书签',
    'no_bookmarks'      => '还没有书签',
    'answers'           => '答案',
    'no_answers'        => '目前还没有答案。..',
    'characters'        => '人物',
    'remove'            => '移走',
    'reply'             => '要回答',
    'edit'              => '要改变',
    'cancel'            => '取消',
    'add'               => '添加',
    'markdown'          => '降價標記',
    'recommended'       => '推荐使用',
    'my_website_info'   => '我添加的网站列表',
    'moderation'        => '适度',
    'sign_in'           => '登录',
    'registration'      => '登记注册',
    'site_added'        => '已添加網站',

    'closed'            => '禁止讨论该网站。 作者或工作人员结束了讨论。',
 
    'audits_home_title' => '现场审核',
    'audits_home_desc'  => '正在考虑的地点',
    'num_website'       => ['网站', '网站', '网站'],
    
    'news'              => '新闻及传媒',
    'internet'          => '互联网',
    'culture'           => '文化艺术',
    'software'          => '计划',
    'reference_info'    => '背景资料',
    'reference_help'    => '百科全书、参考书',
    'science'           => '科学与教育',
    'goods'             => '商品和服务',
    'life'              => '家居壁炉',
    'cms'               => 'CMS系统',
    'life_help'         => '儿童、动物、爱好...',
    'security'          => '安全...',
    'society'           => '社会与政治',
    
    'string_length'         => '长度不正确 {name}',
    'website_correctness'   => '网站的地址（URL）不正确',
    'site_replay'           => '这样的网站已经在系统中',

    'data_help'         => '<i class="gray-600">标题格式:</i><br> «LibArea» — 社区<br><br><i class="gray-600">描述(无广告):</i><br> ...网站上有什么？<i>',
    
    'add_category'      => '添加类别',
    'add_website'       => '添加网站',
    'edit_website'      => '更改网站',
    
    'sidebar_info'      => '按主题标题系统化的网站目录。',
    'banner_info'       => '带有注释和屏幕截图的网站目录。 分面分类，搜索。 书签资源与投票的网站，程序，评级的能力',
    
    'main_title'         => '网站目录',
    'main_desc'          => '按时间顺序排列的目录中的站点列表。 能够搜索，书签，按受欢迎程度排序',
    
    'deleted_title'     => '远程站点',
    'deleted_desc'      => '...',
    'audits_title'      => '现场审核',
    'audits_desc'       => '...',
    
    'all'               => '全部',
    'github'            => 'GitHub',
    'forum'             => '论坛',
    'blog'              => '博客',
    'portal'            => '门户网站',
    'reference'         => '百科全书',
    
    'top_title'         => '{name} -按受欢迎程度划分的网站',
    'top_desc'          => '按主题公布的网站名单 {description_info}',
    'all_title'         => '{name} -类别，按日期划分的网站',
    'all_desc'          => '类别中按时间顺序排列的网站 {description_info}',
];

==> v0.5.7.zip: libarea/app/Languages/zh_TW/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => '更详细',
    'category'          => '类别',
    'categories'        => '类别',
    'audits'            => '审计',
    'soft'              => '软件',
    'website'           => '网站',
    'websites'          => '网站',
    'comments'          => '评论',
    'on_website'        => '到网站',
    'deleted'           => '已删除',
    'facets'            => '方面',
    'favorites'         => '书签',
    'menu'              => '菜单',
    'no'                => '非也',
    'yes'               => '是的',
    'title'             => '标题',
    'description'       => '资料描述',
    'catalog'           => '目录',
    'find'              => '找到',
    'help'              => '提示',
    'deny_replies'      => '禁止回应？',
    'posted'            => '张贴？',
    'necessarily'       => '需要填写',
    'status'            => '链接状态',
    'refresh'           => '刷新',
    'there_program'     => '有计划吗？',
    'there_forum'       => '网站上有论坛吗？',
    'there_portal'      => '这是传送门吗？',
    'there_blog'        => '这是个人博客吗？',
    'there_reference'   => '这是一个参考网站（百科全书）吗？',
    'there_goods'       => '该网站是否提供产品和服务？',
    'hosted_github'     => '程序是否托管在GitHub上？',
    'url_github'        => 'GitHub上存储库的URL',
    'related_posts'     => '相关职位',
    'desc_formed'       => '描述正在形成',
    'by_date'           => '按日期计算',
    'top'               => '最佳',
    'top_view'          => '按评级划分',
    'new_sites'         => '新网站',
    'audits_view'       => '需要考虑',
    'deleted_view'      => '已删除',
    'my_website'        => '我的网站',
    'no_website'        => '目前还没有网站',
    'bookmarks'         => '按网站划分的书签',
    'bookmarks_view'    => '我的书签',
    'no_bookmarks'      => '还没有书签',
    'answers'           => '答案',
    'no_answers'        => '目前还没有答案。..',
    'characters'        => '人物',
    'remove'            => '移走',
    'reply'             => '要回答',
    'edit'              => '要改变',
    'cancel'            => '取消',
    'add'               => '添加',
    'markdown'          => '降價標記',
    'recommended'       => '推荐使用',
    'my_website_info'   => '我添加的网站列表',
    'moderation'        => '适度',
    'sign_in'           => '登录',
    'registration'      => '登记注册',
    'site_added'        => '已添加網站',

    'closed'            => '禁止讨论该网站。 作者或工作人员结束了讨论。',

    'screenshot_time'   => '截屏可能需要一些時間。',
 
    'audits_home_title' => '现场审核',
    'audits_home_desc'  => '正在考虑的地点',
    'num_website'       => ['网站', '网站', '网站'],
    
    'news'              => '新闻及传媒',
    'internet'          => '互联网',
    'culture'           => '文化艺术',
    'software'          => '计划',
    'reference_info'    => '背景资料',
    'reference_help'    => '百科全书、参考书',
    'science'           => '科学与教育',
    'business'          => '商业',
    'life'              => '家居壁炉',
    'cms'               => 'CMS系统',
    'life_help'         => '儿童、动物、爱好...',
    'security'          => '安全...',
    'society'           => '社会与政治',

    'contact_information'   => '联系信息',
    'telephone'             => '电话',
    'email'                 => 'Email',
    'vk'                    => 'VKontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => '长度不正确 {name}',
    'website_correctness'   => '网站的地址（URL）不正确',
    'site_replay'           => '这样的网站已经在系统中',

    'data_help'         => '<i class="gray-600">标题格式:</i><br> «LibArea» — 社区<br><br><i class="gray-600">描述(无广告):</i><br> ...网站上有什么？',
    'admin_help'         => '僅對員工開放的封閉部分',
    
    'add_category'      => '添加类别',
    'add_website'       => '添加网站',
    'edit_website'      => '更改网站',
    
    'sidebar_info'      => '按主题标题系统化的网站目录。',
    'banner_info'       => '带有注释和屏幕截图的网站目录。 分面分类，搜索。 书签资源与投票的网站，程序，评级的能力',
    
    'main_title'        => '网站目录',
    'main_desc'         => '按时间顺序排列的目录中的站点列表。 能够搜索，书签，按受欢迎程度排序',
    
    'deleted_title'     => '远程站点',
    'audits_title'      => '现场审核',
    
    'all'               => '全部',
    'github'            => 'GitHub',
    'forum'             => '论坛',
    'blog'              => '博客',
    'portal'            => '门户网站',
    'reference'         => '百科全书',
    'goods'             => '商品和服务',
    
    'top_title'         => '{name} -按受欢迎程度划分的网站',
    'top_desc'          => '按主题公布的网站名单 {description_info}',
    'all_title'         => '{name} -类别，按日期划分的网站',
    'all_desc'          => '类别中按时间顺序排列的网站 {description_info}',
];
